Index: chrome/browser/zygote_main_linux.cc |
diff --git a/chrome/browser/zygote_main_linux.cc b/chrome/browser/zygote_main_linux.cc |
index 20b03524db89cd23e7c5e80c3301a53738701251..b4dd7bea1f4872c131907a65767943b87ad5aa99 100644 |
--- a/chrome/browser/zygote_main_linux.cc |
+++ b/chrome/browser/zygote_main_linux.cc |
@@ -50,9 +50,10 @@ |
#include "unicode/timezone.h" |
-#if defined(ARCH_CPU_X86_FAMILY) && !defined(CHROMIUM_SELINUX) |
+#if defined(ARCH_CPU_X86_FAMILY) && !defined(CHROMIUM_SELINUX) && \ |
+ !defined(__clang__) |
// The seccomp sandbox is enabled on all ia32 and x86-64 processor as long as |
// we aren't using SELinux. |
Nico
2010/09/17 23:52:40
is there a reason for this?
@@ -50,9 +50,10 @@ |
// The seccomp sandbox is enabled on all ia32 and x86-64 processor as long as |
-// we aren't using SELinux. |
+// we aren't using SELinux or clang. |
Nico
2010/09/17 23:52:40
Evan Martin
2010/09/17 23:54:06
Seccomp is really gcc specific right now.
|
#define SECCOMP_SANDBOX |
#endif |